# coding: utf-8
u"""Данный модуль является IoC-контейнером.

Используется для связывания объектов и классов проекта с общей кодовой базой.
При необходимости использования в общей кодовой базе объектов проекта,
нужно добавить переменные со значением _empty в данный модуль.
"""

# Пустой класс (Sentinel), чтобы не присваивать None, т.к. None может быть
# хранимым значением.
_empty = type('', tuple(), dict())

auth_controller = _empty


def register(name, value):
    u"""Регистрирует в контейнере значение *value* под именем *name*.

    *name* должен быть объявлен в модуле и равен *_empty*.
    """
    assert name in globals()
    assert globals()[name] is _empty

    globals()[name] = value

    return value


def get(name):
    u"""Возвращает содержимое с именем *name*.

    *name* должен быть предварительно зарегистрирован через **register**.
    """
    assert name in globals(), u'Object is not registered'
    assert globals()[name] is not _empty

    return globals()[name]
